@@ -1,7 +1,7 @@
 package Bencher;
 
 our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -940,7 +940,7 @@ $SPEC{bencher} = {
     v => 1.1,
     summary => 'A benchmark framework',
     args_rels => {
-        # XXX precision is only relevant when action=bench
+        # XXX precision & precision_limit is only relevant when action=bench
     },
     args => {
         scenario_file => {
@@ -992,6 +992,27 @@ _
         },
         precision => {
             summary => 'Precision, will be passed to Benchmark::Dumb',
+            description => <<'_',
+
+This setting overrides `default_precision` property in the scenario.
+
+_
+            schema => ['float*', between=>[0,1]],
+        },
+        precision_limit => {
+            summary => 'Set maximum (=smallest number) precision',
+            description => <<'_',
+
+Instead of setting `precision` which forces a single value, you can also set
+this `precision_limit` setting. If the precision in the scenario is higher
+(=number is smaller) than this limit, then this limit is used. For example, if
+the scenario specifies `default_precision` 0.001 and `precision_limit` is set to
+0.005 then 0.005 is used.
+
+This setting is useful on slower computers which might not be able to reach the
+required precision before hitting maximum number of iterations.
+
+_
             schema => ['float*', between=>[0,1]],
         },
         action => {
@@ -1596,6 +1617,11 @@ sub bencher {
         }
 
         my $precision = $args{precision} // $parsed->{default_precision} // 0;
+        if (defined($args{precision_limit}) && $precision < $args{precision_limit}) {
+            $precision = $args{precision_limit};
+        }
+        $envres->[3]{'func.precision'} = $precision if $return_resmeta;
+
         $log->tracef("Running benchmark (precision=%g) ...", $precision);
         my $tres = Benchmark::Dumb::_timethese_guts(
             $precision,
@@ -1705,7 +1731,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.25 of Bencher (from Perl distribution Bencher), released on 2016-01-08.
+This document describes version 0.26 of Bencher (from Perl distribution Bencher), released on 2016-01-08.
 
 =head1 SYNOPSIS
 
@@ -1882,6 +1908,21 @@ Add participants.
 
 Precision, will be passed to Benchmark::Dumb.
 
+This setting overrides C<default_precision> property in the scenario.
+
+=item * B<precision_limit> => I<float>
+
+Set maximum (=smallest number) precision.
+
+Instead of setting C<precision> which forces a single value, you can also set
+this C<precision_limit> setting. If the precision in the scenario is higher
+(=number is smaller) than this limit, then this limit is used. For example, if
+the scenario specifies C<default_precision> 0.001 and C<precision_limit> is set to
+0.005 then 0.005 is used.
+
+This setting is useful on slower computers which might not be able to reach the
+required precision before hitting maximum number of iterations.
+
 =item * B<raw> => I<bool>
 
 Show "raw" data.
